@@ -2,7 +2,7 @@ package HTML::SocialMeta::Base;
 use Moo;
 use Carp;
 
-our $VERSION = '0.730001';
+our $VERSION = '0.730002';
 
 use MooX::LazierAttributes qw/rw ro lzy/;
 use MooX::ValidateSubs;
@@ -80,8 +80,8 @@ sub _build_field {
 }
 
 sub _convert_field {
-    $_[1] =~ s/_/:/g;
-    return $_[0]->provider_convert( $_[1] );
+    (my $field = $_[1]) =~ s/_/:/g;
+    return $_[0]->provider_convert( $field );
 }
 
 sub _no_card_type {
@@ -113,7 +113,7 @@ builds and returns the Meta Tags
 
 =head1 VERSION
 
-Version 0.730001
+Version 0.730002
 
 =cut
 
